@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.0 2009/06/28 20:43:12 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.1 2011/08/28 11:40:13 jcb Exp $
  * game.c
  * Routines for manipulating game data structures.
  */
@@ -14,7 +14,7 @@
  *                                                           *
  *************************************************************/
  
-static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.0 2009/06/28 20:43:12 jcb Rel $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.1 2011/08/28 11:40:13 jcb Exp $";
 
 #include "game.h"
 #include "sysdep.h"
@@ -1654,8 +1654,26 @@ int game_handle_cmsg(Game *g, CMsgMsg *cm)
       affected_id = m->id;
       if ( chk ) {
 	if ( ! (g->state == Discarding
-		&& (g->protversion < 1010 || g->whence != FromDiscard)
-		&& g->player == s ) ) {
+	    && g->player == s
+	    /* before 1010, adding to pung was allowed anytime, which
+	       it shouldn't have been.
+	       Since version 1.11 (protocol 1110), 
+	       it is allowed to add to a pung that you have just claimed.
+	    */
+	    && (g->protversion < 1010 
+	      || g->whence != FromDiscard
+	      || (g->protversion >= 1110
+		/* the last discard was claimed by us for Pung */
+		/* these two conditions are not prima facie enough
+		   to guarantee that the last thing we did was actually
+		   to make the pung, but in fact they are. There's no
+		   way we can reach this state apart from that. */
+		&& g->claims[s] == PungClaim
+		/* the pung just claimed must be the one we're
+		   adding the tile to */
+		&& g->tile == m->tile)
+		)
+		) ) {
 	  g->cmsg_err = "Can't make a kong now";
 	  return -1;
 	}
