@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/newmj/RCS/greedy.c,v 11.13 2006/12/16 17:14:55 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.0 2009/06/28 20:43:12 jcb Rel $
  * greedy.c
  * This is a computer player. Currently offensive only.
  * Options not documented.
@@ -15,7 +15,7 @@
  *                                                           *
  *************************************************************/
  
-static const char rcs_id[] = "$Header: /home/jcb/newmj/RCS/greedy.c,v 11.13 2006/12/16 17:14:55 jcb Exp $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.0 2009/06/28 20:43:12 jcb Rel $";
 
 static int debugeval = 0;
 #include <stdlib.h>
@@ -48,6 +48,8 @@ int our_id = 0;
 PlayerP our_player;
 seats our_seat;
 
+static char *password = NULL;
+
 static FILE *debugf;
 
 /* New style strategy */
@@ -128,8 +130,8 @@ static int chances_to_win(PlayerP p);
 #define send_packet(m) client_send_packet(the_game,(PMsgMsg *)m)
 
 static void usage(char *pname,char *msg) {
-  fprintf(stderr,"%s: %s\nUsage: %s [ --id N ] [ --name NAME ] [ --server ADDR ]\n\
-  [ undocumented options ]\n",
+  fprintf(stderr,"%s: %s\nUsage: %s [ --id N ] [ --name NAME ] [ --password PASSWORD ] [ --server ADDR ]\n\
+  [ strategy options ]\n",
 	  pname,msg,pname);
   exit(1);
 }
@@ -159,6 +161,9 @@ int main(int argc, char *argv[]) {
     } else if ( strcmp(argv[i],"--name") == 0 ) {
       if ( ++i == argc ) usage(argv[0],"missing argument to --name");
       name = argv[i];
+    } else if ( strcmp(argv[i],"--password") == 0 ) {
+      if ( ++i == argc ) usage(argv[0],"missing argument to --password");
+      password = argv[i];
     } else if ( strcmp(argv[i],"--debug") == 0 ) {
       if ( ++i == argc ) usage(argv[0],"missing argument to --debug");
       debugeval = atoi(argv[i]);
@@ -183,7 +188,7 @@ int main(int argc, char *argv[]) {
       parsefloatlist(argv[i],suitness);
     } else if ( strcmp(argv[i],"--magic") == 0 ) {
       FILE *f;
-      int j;
+      unsigned int j;
       if ( ++i == argc ) usage(argv[0],"missing argument to --magic");
       f = fopen(argv[i],"r");
       if ( f == NULL ) {
@@ -288,6 +293,24 @@ static int despatch_line(char *line) {
     our_id = the_game->players[0]->id;
     our_player = the_game->players[0];
     break;
+  case CMsgAuthReqd:
+    {
+      CMsgAuthReqdMsg *carm = (CMsgAuthReqdMsg *)cm;
+      PMsgAuthInfoMsg paim;
+      paim.type = PMsgAuthInfo;
+      if ( strncmp(carm->authtype,"basic",16) != 0 ) {
+	warn("Asked for unknown authorization type %.16s",carm->authtype);
+	exit(1);
+      }
+      strcpy(paim.authtype,"basic");
+      if ( password == NULL ) {
+	warn("Asked for password, don't have it");
+	exit(1);
+      }
+      paim.authdata = password;
+      send_packet(&paim);
+    }
+    break;
     /* In these cases, our seat might have changed, so we need to calculate it */
   case CMsgGame:
     /* In this case, we need to ask for the game options */
@@ -420,6 +443,9 @@ static int despatch_line(char *line) {
   case CMsgPlayerOptionSet:
     /* we don't recognize any options, so ignore it */
     break;
+  case CMsgRedirect:
+    warn("Redirect command not currently supported");
+    exit(1);
   }
   return 1;
 }
