@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/newmj/RCS/gui.h,v 11.32 2006/01/28 23:22:04 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/gui.h,v 12.0 2009/06/28 20:43:12 jcb Rel $
  * gui.h
  * type defns and forward declarations for the gui module.
  */
@@ -111,6 +111,12 @@ typedef struct _PlayerDisp {
   GtkWidget *claimlab; /* and the label inside it */
   int claim_serial; /* the discard for which this window was popped up */
   int claim_time; /* time popped up (in millisecs since start of program) */
+
+  /* this is a label widget which is put the right of each player when
+     the wall is shown, to use the otherwise empty space. It displays the
+     same info as the info window. It's only used in GTK2, because in order to
+     make it clear which label goes with which, we use rotated text. */
+  GtkLabel *infolab;
 } PlayerDisp;
 
 /* This is a one use structure representing the dialog box
@@ -170,6 +176,13 @@ typedef enum {
  DialogsBelow = 2,
  DialogsPopup = 3 } DialogPosition;
 
+/* when to sort the tiles in our hand */
+typedef enum {
+  SortAlways = 0,
+  SortDeal = 1,
+  SortNever = 2,
+} SortTiles;
+
 /* Whether to file fault reports over the network */
 typedef enum {
   DebugReportsUnspecified = 0,
@@ -228,6 +241,8 @@ void do_chow(GtkWidget *w, gpointer data);
 gint doubleclicked(GtkWidget *w, GdkEventButton *eb,gpointer data);
 void ds_dialog_init(void);
 void ds_dialog_popup(void);
+void end_dialog_init(void);
+void end_dialog_popup(void);
 void error_dialog_init(void);
 void error_dialog_popup(char *msg);
 void game_option_init(void);
@@ -239,9 +254,10 @@ void messagewindow_init(void);
 void nag_popup(void);
 void option_reset_callback(GtkWidget *w, gpointer data);
 void option_updater_callback(GtkWidget *w, gpointer data);
-void open_connection(GtkWidget *w UNUSED, gpointer data, int fd);
+void open_connection(GtkWidget *w UNUSED, gpointer data, int fd, char *newaddr);
 void open_dialog_init(char *idt, char *nt);
 void open_dialog_popup(GtkWidget *w UNUSED, gpointer data);
+void password_showraise(void);
 void playing_prefs_init(void);
 void prefs_updater_callback(GtkWidget *w, gpointer data);
 int read_or_update_rcfile(char *rcfile,
@@ -289,6 +305,11 @@ extern int monitor; /* if 1, send no messages other than in direct
 		       response to user action. Used for monitoring
 		       a stream in debugging. */
 
+extern int game_over; /* if the game is over, but we're waiting for the user
+			 to confirm the disconnect. In this state, we do
+			 not close our connection when the other end closes.
+		      */
+
 extern GdkPixmap **tilepixmaps[]; /* pixmaps for the tiles */
 
 extern GtkWidget *topwindow; /* main window */
@@ -316,6 +337,9 @@ extern GtkWidget *ds_dialog;
 /* dialog box for continuing with next hand */
 extern GtkWidget *continue_dialog;
 
+/* dialog box for disconnect at end of game */
+extern GtkWidget *end_dialog;
+
 /* dialog for opening connection */
 extern GtkWidget *open_dialog;
 extern GtkWidget *openmenuentry, *newgamemenuentry, *resumegamemenuentry, 
@@ -371,11 +395,16 @@ extern char name[]; /* player's name */
 extern char main_font_name[]; /* font used in all dialogs etc */
 extern char text_font_name[]; /* font used for text in windows */
 extern char fallback_text_font_name[]; /* one that worked */
+#ifdef GTK2
+extern int use_system_gtkrc; /* as it says */
+extern char gtk2_rcfile[512]; /* gtkrc file to use */
+#endif
 extern char table_colour_name[]; /* colour of the table background */
 extern int animate; /* do fancy animation */
 extern int nopopups; /* suppress automatic popup of message/scoring windows */
 extern int tiletips; /* show tiletips constantly */
 extern int showwall; /* show the wall or not */
+extern int sort_tiles; /* when to sort tiles */
 extern int info_windows_in_main; /* should the message and game info windows
 				    be included in the main window, or
 				    be separate popups ? */
