@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/newmj/RCS/player.c,v 11.8 2004/05/15 15:07:51 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/player.c,v 12.0 2009/06/28 20:43:13 jcb Rel $
  * player.c
  * Implements functions on players.
  */
@@ -14,7 +14,7 @@
  *                                                           *
  *************************************************************/
 
-static const char rcs_id[] = "$Header: /home/jcb/newmj/RCS/player.c,v 11.8 2004/05/15 15:07:51 jcb Exp $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/player.c,v 12.0 2009/06/28 20:43:13 jcb Rel $";
 
 #define PLAYER_C /* so that PlayerP is not const */
 #include "player.h"
@@ -74,6 +74,7 @@ void player_newhand(PlayerP p,TileWind w) {
   p->err = NULL;
   p->wind = w;
   p->num_concealed = 0;
+  p->discard_hint = -1;
   for ( i = 0; i < MAX_CONCEALED; i++ ) (p->concealed)[i] = HiddenTile;
   for ( i = 0; i < MAX_TILESETS; i++ ) {
     (p->tilesets)[i].type = Empty;
@@ -168,17 +169,40 @@ static int add_tile(PlayerP p, Tile t) {
   return 1;
 }
 
+int player_set_discard_hint(PlayerP p, int h) {
+  if ( h < 0 || h >= p->num_concealed ) {
+    warn("player_discard_hint: out of range hint %d",h);
+    return 0;
+  }
+  p->discard_hint = h;
+  return 1;
+}
+
 /* remove_tile: removes one instance of t from p's concealed tiles.
    Returns 1 on success, 0 on failure.
    Should not be called on hidden players.
 */
 static int remove_tile(PlayerP p, Tile t) {
-  int i;
+  int i,d;
 
   assert(!pflag(p,Hidden)); /* nonsense to call this on hidden player */
 
   i = 0;
-  while ( i < p->num_concealed && p->concealed[i] != t ) i++ ;
+  d = p->discard_hint;
+  p->discard_hint = -1; /* clear it whatever happens next */
+  if ( d >= 0 ) {
+    if ( d >= p->num_concealed ) {
+      warn("Bad discard hint %d -- too big",d);
+      d = -1;
+    } else if ( p->concealed[d] != t ) {
+      warn("Bad discard hint -- tile %d is not %d",d,t);
+      d = -1;
+    }
+  }
+  if ( d >= 0 ) 
+    i = d;
+  else
+    while ( i < p->num_concealed && p->concealed[i] != t ) i++ ;
   if ( i == p->num_concealed ) return 0;
   while ( i+1 < p->num_concealed ) {
     p->concealed[i] = p->concealed[i+1];
@@ -831,6 +855,28 @@ void player_sort_tiles(PlayerP p) {
   }
 }
 
+/* move a tile */
+int player_reorder_tile(PlayerP p, int old, int new) {
+  int i;
+  if ( old < 0 || new < 0 
+    || old >= p->num_concealed || new >= p->num_concealed ) {
+    warn("player_reorder_tile: arguments out of range %d, %d",old,new);
+    return 0;
+  }
+  if ( old == new ) return 1;
+  Tile t = p->concealed[old];
+  if ( new > old ) {
+    for (i = old+1; i <= new; i++)
+      p->concealed[i-1] = p->concealed[i];
+    p->concealed[new] = t;
+  } else {
+    for (i = old-1; i >= new; i--)
+      p->concealed[i+1] = p->concealed[i];
+    p->concealed[new] = t;
+  }
+  return 1;
+}
+
 /* This function generates a string repn of a players tiles. */
 void player_print_tiles(char *buf, PlayerP p, int hide) {
   int i,j;
