@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/newmj/RCS/sysdep.c,v 11.32 2006/01/24 22:06:59 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.1 2009/07/10 14:46:14 jcb Rel $
  * sysdep.c
  * By intention, this file contains all functions that might need
  * fiddling with to cope with different variants of Unix.
@@ -21,10 +21,21 @@
  *                                                           *
  *************************************************************/
 
-static const char rcs_id[] = "$Header: /home/jcb/newmj/RCS/sysdep.c,v 11.32 2006/01/24 22:06:59 jcb Exp $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.1 2009/07/10 14:46:14 jcb Rel $";
 
 #include "sysdep.h"
 #include <string.h>
+/* This is missing in my windows mingw */
+#ifdef WIN32
+char *index(const char *s, int c) {
+  while ( 1 ) {
+    if (*s == 0) return NULL;
+    else if (*s == c) return (char *)s;
+    s++;
+  }
+}
+#endif
+
 #include <fcntl.h>
 #include <errno.h>
 
@@ -692,6 +703,55 @@ void rand_seed(int s) {
   srand(seed = s);
 }
 
+/* This is like strmcat, but it also quotes the string (in a system
+   dependent way) for adding it to a shell command line.
+*/
+char *qstrmcat(char *dest, const char *src, int len) {
+  char *d = dest;
+  char *s = (char *)src;
+  while ( *d ) d++;
+  if ( len == 0 ) return dest;
+#ifdef WIN32
+  *d = '"'; d++; len--;
+#else
+  *d = '\''; d++; len--;
+#endif
+  while ( *s && len > 0 ) {
+#ifdef WIN32
+    if ( *s == '"' ) {
+      *d++ = '"'; len--;
+      if ( len > 0 ) {
+	*d++ = *s++; len--;
+      }
+    } else {
+      *d++ = *s++; len--;
+    }
+#else
+    if ( *s == '\'' || *s == '\\' ) {
+      *d++ = '\''; len--;
+      if ( len > 2 ) {
+	*d++ = '\\'; len--;
+	*d++ = *s++; len--;
+	*d++ = '\''; len--;
+      }
+    } else {
+      *d++ = *s++; len--;
+    }
+#endif
+  }
+  if ( len > 0 ) {
+#ifdef WIN32
+    *d++ = '"'; len--;
+#else
+    *d++ = '\''; len--;
+#endif
+  }
+  if ( len == 0 ) d--;
+  *d = 0;
+  return dest;
+}
+
+
 /* utility function for following: return "NULL" for null string */
 char *nullprotect(char *s) { return s ? s : "NULL"; }
 
@@ -867,7 +927,7 @@ int gettimeofday(struct timeval *tv, void *tz UNUSED) {
   ll <<= 32;
   ll |= ft.dwLowDateTime;
   /* this magic number comes from Microsoft's knowledge base ' */
-  ll -= 116447360000000000;  /* 100 nanoseconds since 1970 */
+  ll -= 116447360000000000LL;  /* 100 nanoseconds since 1970 */
   ll /= 10; /* microseconds since 1970 */
   sec = (long)(ll / 1000000);
   usec = (long)(ll - 1000000*((LONGLONG) sec));
